spacepy.datamodel.readJSONheadedASCII — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »

# spacepy.datamodel.readJSONheadedASCII

`spacepy.datamodel.` `readJSONheadedASCII`(fname, mdata=None, comment='#', convert=False)

  read JSON-headed ASCII data files into a SpacePy datamodel

  Parameters: | fname : str or list Filename(s) to read data from
  Returns: | mdata: spacepy.datamodel.SpaceData : SpaceData with the data and metadata from the file
  Other Parameters:
  | mdata : spacepy.datamodel.SpaceData (optional) supply metadata object, otherwise is read from fname (default None) comment: str (optional) : comment string in file to be read; lines starting with comment are ignored (default ‘#’) convert: bool or dict-like (optional) : If True, uses common names to try conversion from string. If a dict- like then uses the functions specified as the dict values to convert each element of ‘key’ to a non-string

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- datamodel - easy to use general data model »